summaryrefslogtreecommitdiffstats
path: root/libkdegames/kgame/dialogs/kgamedialogconfig.h
diff options
context:
space:
mode:
Diffstat (limited to 'libkdegames/kgame/dialogs/kgamedialogconfig.h')
-rw-r--r--libkdegames/kgame/dialogs/kgamedialogconfig.h18
1 files changed, 9 insertions, 9 deletions
diff --git a/libkdegames/kgame/dialogs/kgamedialogconfig.h b/libkdegames/kgame/dialogs/kgamedialogconfig.h
index 7c42d05d..a7f309ac 100644
--- a/libkdegames/kgame/dialogs/kgamedialogconfig.h
+++ b/libkdegames/kgame/dialogs/kgamedialogconfig.h
@@ -53,7 +53,7 @@ class KDE_EXPORT KGameDialogConfig : public TQWidget
Q_OBJECT
TQ_OBJECT
public:
- KGameDialogConfig(TQWidget* tqparent = 0);
+ KGameDialogConfig(TQWidget* parent = 0);
virtual ~KGameDialogConfig();
/**
@@ -137,7 +137,7 @@ private:
* The main game configuration widget.
*
* It currently contains a line edit for the name of the player only. You can
* add widgets by using the KGameDialogGeneralConfig as tqparent parameter as it
* uses TQLayout::autoAdd == true.
* @author Andreas Beckermann <b_mann@gmx.de>
**/
@@ -152,17 +152,17 @@ public:
* edit widget to change the player name only.
*
* If you just want to add more widgets you can just create your widgets
* with the KGameDialogGeneralConfig as tqparent as it uses
* TQLayout::setAutoAdd(true).
*
- * @param tqparent Parent widget for this dialog.
+ * @param parent Parent widget for this dialog.
* @param initializeGUI If you really don't want to use the
* predefined widget and/or tqlayout use FALSE here. Note that then none
* of the predefined widgets (currently only the name of the player)
* will exist anymore.
*
**/
- KGameDialogGeneralConfig(TQWidget* tqparent = 0, bool initializeGUI = true);
+ KGameDialogGeneralConfig(TQWidget* parent = 0, bool initializeGUI = true);
virtual ~KGameDialogGeneralConfig();
/**
@@ -215,7 +215,7 @@ class KDE_EXPORT KGameDialogNetworkConfig : public KGameDialogConfig
Q_OBJECT
TQ_OBJECT
public:
- KGameDialogNetworkConfig(TQWidget* tqparent = 0);
+ KGameDialogNetworkConfig(TQWidget* parent = 0);
virtual ~KGameDialogNetworkConfig();
@@ -282,7 +282,7 @@ class KGameDialogMsgServerConfig : public KGameDialogConfig
Q_OBJECT
TQ_OBJECT
public:
- KGameDialogMsgServerConfig(TQWidget* tqparent = 0);
+ KGameDialogMsgServerConfig(TQWidget* parent = 0);
virtual ~KGameDialogMsgServerConfig();
virtual void submitToKGame(KGame*, KPlayer*) {}
@@ -316,7 +316,7 @@ class KGameDialogChatConfig : public KGameDialogConfig
Q_OBJECT
TQ_OBJECT
public:
- KGameDialogChatConfig(int chatMsgId, TQWidget* tqparent = 0);
+ KGameDialogChatConfig(int chatMsgId, TQWidget* parent = 0);
virtual ~KGameDialogChatConfig();
virtual void setKGame(KGame* g);
@@ -338,7 +338,7 @@ class KGameDialogConnectionConfig : public KGameDialogConfig
Q_OBJECT
TQ_OBJECT
public:
- KGameDialogConnectionConfig(TQWidget* tqparent = 0);
+ KGameDialogConnectionConfig(TQWidget* parent = 0);
virtual ~KGameDialogConnectionConfig();
virtual void setKGame(KGame* g);
@@ -137,7 +137,7 @@ private:
*
* It currently contains a line edit for the name of the player only. You can
- * add widgets by using the KGameDialogGeneralConfig as tqparent parameter as it
+ * add widgets by using the KGameDialogGeneralConfig as parent parameter as it
* uses TQLayout::autoAdd == true.
* @author Andreas Beckermann <b_mann@gmx.de>
@@ -152,17 +152,17 @@ public:
*
* If you just want to add more widgets you can just create your widgets
- * with the KGameDialogGeneralConfig as tqparent as it uses
+ * with the KGameDialogGeneralConfig as parent as it uses
* TQLayout::setAutoAdd(true).
*